/* Ported to BeOS by Daniel Berlin
 */
/****************************************************************************
 * ioled.c:  Simple device driver to handle the iOpener's front-panel
LED's.
 *
 * Author:  Steven M. Doyle <grep@doyle.net>
 *   Date:  4/1/2000 (but not an april fool's joke)
 *
 * Copyright (c)2000 Steven M. Doyle.
 *
 * Thanks to Robert Rose <rarose@io.com> for discovering how to make the
 * lights work in the first place and posting it for all to play with.
 *
 * This code has been released under GPL.  See http://www.gnu.org for more
 * information.
 *

*----------------------------------------------------------------------------
 * Instructions:
 *
 * To Compile:
 * gcc -O6 -Wall -Wstrict-prototypes -O2 -fomit-frame-pointer -pipe \
 *     -fno-strength-reduce -DMODULE -D__KERNEL__ -c ioled.c -o ioled.o
 *
 * To use:
 * - insert as normal
 * - mknod /dev/ioled c 10 240
 * - echo characters at the device.  The following characters have
meanings:
 *    '0' - Turn the Mail LED off
 *    '1' - Turn the Mail LED on
 *    '2' - Turn the Telephone LED off
 *    '3' - Turn the Telephone LED on
 *
 * - example:  echo 13 > /dev/ioled # Turn both LED's on
 *
 * This has not been heavily tested.  Use this module at your own risk.
Let
 * me know if there are any problems.

*****************************************************************************/

#include <drivers/Drivers.h>
#include <drivers/KernelExport.h>

#include <malloc.h>
#include <string.h>
#define DEVICE_NAME "misc/ioled"
#include <drivers/ISA.h>
static isa_module_info *isa;
static status_t ioled_open(const char *name, uint32 mode, void **cookie)
{
		return B_OK;
}

static status_t ioled_close(void *cookie)
{
		return B_OK;
}
static status_t ioled_free(void *cookie)
{
		return B_OK;
}
static char isa_name[]=B_ISA_MODULE_NAME;
static status_t ioled_write(void *cookie, off_t pos, const void *buffer, size_t *len)
                        {
  char a;
  int i;

  for (i = 0; i < *len; i++) {
    a = (*isa->read_io_8)(0x404C);
    switch(((uchar *)buffer)[i]) {
    case '1': a &= ~1; break;
    case '0': a |= 1;  break;
    case '3': a &= ~2; break;
    case '2': a |= 2;  break;
    }
    (*isa->write_io_8)( 0x404C,a);
  }
     
  return B_OK;
}
status_t init_hardware()
{
		return B_OK;
}
const char **publish_devices()
{
		static const char *devices[]={
				DEVICE_NAME,NULL
		};
		return devices;
}
static  status_t  ioled_ioctl(void *cookie, uint32 op, void *data, size_t len)
{
		return ENOSYS;
}
static status_t ioled_read(void *cookie, off_t pos, void *buffer, size_t *len)
{
		*len=0;
		return -EIO;
}
device_hooks *find_device(const char *name)
{
		static device_hooks hooks = {
				&ioled_open,
				&ioled_close,
				&ioled_free,
				&ioled_ioctl,
				&ioled_read,
				&ioled_write,
				NULL,
				NULL,
				NULL,
				NULL
		};
		if (!strcmp(name, DEVICE_NAME))
				return &hooks;
		return NULL;
}
status_t init_driver()
{
	get_module(isa_name, (module_info **) &isa);
	return B_OK;
}
void uninit_driver()
{put_module(isa_name);
}

